@@ -1,5 +1,6 @@
 package org.gcube.applicationsupportlayer.social;
 
+import java.text.SimpleDateFormat;
 import java.util.Date;
 import java.util.List;
 import java.util.UUID;
@@ -576,4 +577,33 @@ public class ApplicationNotificationsManager extends SocialPortalBridge implemen
 
 		return saveNotification(not);
 	}
+	/**
+	 * {@inheritDoc}
+	 */
+	@Override
+	public boolean notifyNewCalendarEvent(String userIdToNotify, String eventTitle, String eventDescription, String eventType, Date startDate, Date endingDate) {
+		
+		SimpleDateFormat DATE_FORMAT = new SimpleDateFormat("dd-MM-yy at HH:mm");
+		
+		String notificationText = "created " +escapeHtml(eventTitle) + " in the " + aslSession.getGroupName() + " shared calendar. " +
+				"Category: " + eventType + " From: " + DATE_FORMAT.format(startDate);
+		if (endingDate != null) {
+			DATE_FORMAT = new SimpleDateFormat("dd/MM/yy");
+			notificationText += " to " + DATE_FORMAT.format(endingDate) + ".";
+		}
+		Notification not = new Notification(
+				UUID.randomUUID().toString(), 
+				NotificationType.NEW_CALENDAR_EVENT, 
+				userIdToNotify, //user no notify
+				"",  //the workflowid 
+				new Date(),
+				getApplicationUrl(), 
+				notificationText,
+				false, 
+				aslSession.getUsername(),
+				aslSession.getUserFullName(), 
+				aslSession.getUserAvatarId());
+
+		return saveNotification(not);
+	}
 }
